var PiePoint = function(name, count, percentage) {
	this.name = name;
	this.count = count;
	this.percentage = percentage;	
}

var PieChart = function(chartId, title) {
	$('#' + chartId)
			.highcharts(
					{
						chart : {
							backgroundColor:'#fff',
							plotBackgroundColor : null,
							plotBorderWidth : null,
							plotShadow : false
						},
						title : {
							text : title,
							align: 'left'
						},
						tooltip : {
							pointFormat : '{series.name}: <b>{point.percentage:.1f}</b> %'
						},
						plotOptions : {
							pie : {
								size:250,
								allowPointSelect : true,
								cursor : 'pointer',
								dataLabels : {
									enabled : true,
									color : '#000000',
									connectorColor : '#000000',
									format : '<b>{point.name}</b>: {point.count} ({point.percentage:.1f}%)'
								}
							}
						},
						series : [ {
							type : 'pie',
							name : 'URL content type distribution',
							data : []
						} ]
					});

}

var UrlContentTypeDistribution = function(containerId, testPlanId) {
	var pieChart = new PieChart(containerId, "URL content type distribution");
	var chart = $("#" + containerId).highcharts();
	getUrlContentTypeData(testPlanId, chart);
}

var addPieData = function(chart,data){
	var points = contentTypeDataFormat(data);
	for(var i=0; i<points.length; i++){
		chart.series[0].addPoint({
	        name: points[i].name,
	        count: points[i].count,
	        y: points[i].percentage
	    });
	}
}

var getUrlContentTypeData = function (testPlanId, chart){
	$.post( testPlanId + "/" + "urlContentTypeCount", 
			{},
			function(data) {
				if (data.success) {
					addPieData(chart, data.result);
				} else {
					return;
				}
			}).error(function(){
				information($.i18n.prop('failed-connect-server'));
			});;
	
}

var contentTypeDataFormat = function (data){
	var points = new Array(); 
	var sum = data[""] + data["text/html;charset=utf8"] + data["application/json;charset=UTF-8"];
	points[0] = new PiePoint("image", data[""], data[""]/sum);
	points[1] = new PiePoint("text/html", data["text/html;charset=utf8"], data["text/html;charset=utf8"]/sum);
	points[2] = new PiePoint("text/html", data["application/json;charset=UTF-8"], data["application/json;charset=UTF-8"]/sum);
	return points;
	
}
